# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: directory_service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64irectory_service.proto\x12\tdirectory\">\n\x12\x46ileLocationUpdate\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x16\n\x0enode_addresses\x18\x02 \x03(\t\"\x1d\n\tFileQuery\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\'\n\rFileLocations\x12\x16\n\x0enode_addresses\x18\x01 \x03(\t\"!\n\x0eUpdateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xaa\x01\n\x10\x44irectoryService\x12P\n\x12UpdateFileLocation\x12\x1d.directory.FileLocationUpdate\x1a\x19.directory.UpdateResponse\"\x00\x12\x44\n\x10GetFileLocations\x12\x14.directory.FileQuery\x1a\x18.directory.FileLocations\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'directory_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILELOCATIONUPDATE']._serialized_start=38
  _globals['_FILELOCATIONUPDATE']._serialized_end=100
  _globals['_FILEQUERY']._serialized_start=102
  _globals['_FILEQUERY']._serialized_end=131
  _globals['_FILELOCATIONS']._serialized_start=133
  _globals['_FILELOCATIONS']._serialized_end=172
  _globals['_UPDATERESPONSE']._serialized_start=174
  _globals['_UPDATERESPONSE']._serialized_end=207
  _globals['_DIRECTORYSERVICE']._serialized_start=210
  _globals['_DIRECTORYSERVICE']._serialized_end=380
# @@protoc_insertion_point(module_scope)



# ai_network_storage/sdk.py
import grpc
import os
from p2p_file_system_pb2_grpc import P2PFileServiceStub
from p2p_file_system_pb2 import FileRequest, FileChunk
from directory_service_pb2_grpc import DirectoryServiceStub
from directory_service_pb2 import FileLocationUpdate

class AINetworkStorageSDK:
    def __init__(self, directory_server_address):
        self.directory_server_address = directory_server_address

    def _get_directory_stub(self):
        return DirectoryServiceStub(grpc.insecure_channel(self.directory_server_address))

    def upload_file(self, node_address, file_path):
        if not os.path.exists(file_path):
            raise FileNotFoundError(f"File not found: {file_path}")
        filename = os.path.basename(file_path)
        with open(file_path, 'rb') as file:
            data = file.read()

        with grpc.insecure_channel(node_address) as channel:
            stub = P2PFileServiceStub(channel)
            def file_chunk_generator():
                with open(file_path, 'rb') as file:
                    while True:
                        piece = file.read(1024)  # Read in chunks of 1KB
                        if not piece:
                            break
                        yield FileChunk(filename=file_path, data=piece)
            response = stub.UploadFile(file_chunk_generator())
            print (response)

        # Update the directory server
        directory_stub = self._get_directory_stub()
        directory_stub.UpdateFileLocation(FileLocationUpdate(filename=filename, node_addresses=[node_address]))
        print(f"File '{filename}' uploaded to node {node_address}")

    def download_file(self, node_address, filename, save_path):
        with grpc.insecure_channel(node_address) as channel:
            stub = P2PFileServiceStub(channel)
            file_stream = stub.DownloadFile(FileRequest(filename=filename))

            with open(save_path, 'wb') as file:
                for data in file_stream:
                    file.write(data.data)

        print(f"File '{filename}' downloaded from node {node_address}")

# Example usage
if __name__ == "__main__":
    sdk = AINetworkStorageSDK("34.172.161.134:50052")
    sdk.upload_file("34.172.161.134:50053", "sample.txt")
    sdk.download_file("34.172.161.134:50053", "example.txt", "exmple.txt")


# Example usage remains the same



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: p2p_file_system.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15p2p_file_system.proto\x12\x03p2p\"\x1f\n\x0b\x46ileRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\x18\n\x08\x46ileData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"+\n\tFileChunk\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"!\n\x0eUploadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32z\n\x0eP2PFileService\x12\x35\n\nUploadFile\x12\x0e.p2p.FileChunk\x1a\x13.p2p.UploadResponse\"\x00(\x01\x12\x31\n\x0c\x44ownloadFile\x12\x10.p2p.FileRequest\x1a\r.p2p.FileData0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'p2p_file_system_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILEREQUEST']._serialized_start=30
  _globals['_FILEREQUEST']._serialized_end=61
  _globals['_FILEDATA']._serialized_start=63
  _globals['_FILEDATA']._serialized_end=87
  _globals['_FILECHUNK']._serialized_start=89
  _globals['_FILECHUNK']._serialized_end=132
  _globals['_UPLOADRESPONSE']._serialized_start=134
  _globals['_UPLOADRESPONSE']._serialized_end=167
  _globals['_P2PFILESERVICE']._serialized_start=169
  _globals['_P2PFILESERVICE']._serialized_end=291
# @@protoc_insertion_point(module_scope)



# setup.py
from setuptools import setup, find_packages

setup(
    name='ai-network-storage',
    version='0.5.0',
    description='SDK for AI Network P2P file sharing system',
    author='kmh4500',
    author_email='kimminhyun@comcom.ai',
    packages=find_packages(),
    install_requires=[
        'grpcio',
        'grpcio-tools'
        # Any other dependencies
    ],
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import p2p_file_system_pb2 as p2p__file__system__pb2


class P2PFileServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UploadFile = channel.stream_unary(
                '/p2p.P2PFileService/UploadFile',
                request_serializer=p2p__file__system__pb2.FileChunk.SerializeToString,
                response_deserializer=p2p__file__system__pb2.UploadResponse.FromString,
                )
        self.DownloadFile = channel.unary_stream(
                '/p2p.P2PFileService/DownloadFile',
                request_serializer=p2p__file__system__pb2.FileRequest.SerializeToString,
                response_deserializer=p2p__file__system__pb2.FileData.FromString,
                )


class P2PFileServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UploadFile(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_P2PFileServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UploadFile': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFile,
                    request_deserializer=p2p__file__system__pb2.FileChunk.FromString,
                    response_serializer=p2p__file__system__pb2.UploadResponse.SerializeToString,
            ),
            'DownloadFile': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=p2p__file__system__pb2.FileRequest.FromString,
                    response_serializer=p2p__file__system__pb2.FileData.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'p2p.P2PFileService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class P2PFileService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UploadFile(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/p2p.P2PFileService/UploadFile',
            p2p__file__system__pb2.FileChunk.SerializeToString,
            p2p__file__system__pb2.UploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/p2p.P2PFileService/DownloadFile',
            p2p__file__system__pb2.FileRequest.SerializeToString,
            p2p__file__system__pb2.FileData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
